Author: Dave Gandy
Description: Font Awesome, the iconic font designed for Bootstrap

# What's New

What's New in the latest version — Font Awesome 3.2

- Follow @fontawesome
- Tweet

Heads up! These docs are for v3.2.1, which is no longer officially supported. Check out the latest version of Font Awesome!

Font Awesome is always getting a little awesome-er. So here's what's new in the latest version, Font Awesome 3.2. Have some ideas for new features? Help contribute.

#### 58 New Icons in 3.2

Requested by the active community on the Font Awesome GitHub project.

#### SCSS Support

A long term solution is now in place for SCSS support. Need SASS? Try sass-convert.

#### Better & Simpler License

SIL OFL 1.1 for font, MIT license for code. No more attribution required, but much appreciated.

#### Pixel Perfection at 14px

Version 3 was re-created from the ground up to be razor sharp at Bootstrap's default 14px.

#### Font Subsetting

Thanks to @grantgordon and @johnsmclay, you can subset to get just the icons you need.

#### Want More Details?

Check out the CHANGELOG on the GitHub project to see what's new and changed.

## New Styles in 3.2

#### Rotated and Flipped Icons

normal
icon-rotate-90
icon-rotate-180
icon-rotate-270
icon-flip-horizontal
icon-flip-vertical

#### Stacked Icons

icon-twitter on icon-check-empty
icon-flag on icon-circle
icon-terminal on icon-sign-blank

#### Better Bulleted Lists

- New bulleted lists
- Fix some old bugs
- And deal with arbitrary
- Font sizes better

## New Icons in 3.2

You asked, Font Awesome delivers with 58 shiny new icons in version 3.2. Want to request new icons? Here's how.
icon-compass
icon-collapse
icon-collapse-top
icon-expand
icon-eur
icon-euro (alias)
icon-gbp
icon-usd
icon-dollar (alias)
icon-inr
icon-rupee (alias)
icon-jpy
icon-yen (alias)
icon-cny
icon-renminbi (alias)
icon-krw
icon-won (alias)
icon-btc
icon-bitcoin (alias)
icon-file
icon-file-text
icon-sort-by-alphabet
icon-sort-by-alphabet-alt
icon-sort-by-attributes
icon-sort-by-attributes-alt
icon-sort-by-order
icon-sort-by-order-alt
icon-thumbs-up
icon-thumbs-down
icon-youtube-sign
icon-youtube
icon-xing
icon-xing-sign
icon-youtube-play
icon-dropbox
icon-stackexchange
icon-instagram
icon-flickr
icon-adn
icon-bitbucket
icon-bitbucket-sign
icon-tumblr
icon-tumblr-sign
icon-long-arrow-down
icon-long-arrow-up
icon-long-arrow-left
icon-long-arrow-right
icon-apple
icon-windows
icon-android
icon-linux
icon-dribbble
icon-skype
icon-foursquare
icon-trello
icon-female
icon-male
icon-gittip
icon-sun
icon-moon
icon-archive
icon-bug
icon-vk
icon-weibo
icon-renren